@@ -5,8 +5,8 @@
 #' @param x A correlation matrix.
 #' @param distance How the distance between each variable should be calculated.
 #'   If `correlation` (default; suited for correlation matrices), the matrix
-#'   will be rescaled to 0-1 (`distance = 0` indicating correlation of 1;
-#'   `distance = 1` indicating correlation of -1). If `raw`, then the matrix
+#'   will be rescaled to 0-1 (`distance = 0` indicating correlation of `1`;
+#'   `distance = 1` indicating correlation of `-1`). If `raw`, then the matrix
 #'   will be used as a distance matrix as-is. Can be others (`euclidean`,
 #'   `manhattan`, ...), in which case it will be passed to `dist()` (see the
 #'   arguments for it).
@@ -32,6 +32,11 @@ cor_sort.easycorrelation <- function(x, distance = "correlation", ...) {
 
   # Restore class and attributes
   attributes(reordered) <- utils::modifyList(attributes(x)[!names(attributes(x)) %in% c("names", "row.names")], attributes(reordered))
+
+  # make sure Parameter columns are character
+  reordered$Parameter1 <- as.character(reordered$Parameter1)
+  reordered$Parameter2 <- as.character(reordered$Parameter2)
+
   reordered
 }
 
@@ -53,7 +58,14 @@ cor_sort.easycormatrix <- function(x, distance = "correlation", ...) {
   reordered <- x[order(x$Parameter), c("Parameter", order)]
 
   # Restore class and attributes
-  attributes(reordered) <- utils::modifyList(attributes(x)[!names(attributes(x)) %in% c("names", "row.names")], attributes(reordered))
+  attributes(reordered) <- utils::modifyList(
+    attributes(x)[!names(attributes(x)) %in% c("names", "row.names")],
+    attributes(reordered)
+  )
+
+  # make sure Parameter columns are character
+  reordered$Parameter <- as.character(reordered$Parameter)
+
   reordered
 }
 
@@ -64,7 +76,11 @@ cor_sort.matrix <- function(x, distance = "correlation", ...) {
   reordered <- x[order, order]
 
   # Restore class and attributes
-  attributes(reordered) <- utils::modifyList(attributes(x)[names(attributes(x)) != "dimnames"], attributes(reordered))
+  attributes(reordered) <- utils::modifyList(
+    attributes(x)[names(attributes(x)) != "dimnames"],
+    attributes(reordered)
+  )
+
   reordered
 }
 
