@@ -132,12 +132,12 @@ cor_test <- function(data,
                      verbose = TRUE,
                      ...) {
   # valid matrix checks
-  if (!x %in% names(data) | !y %in% names(data)) {
-    stop("The names you entered for x and y are not available in the dataset. Make sure there are no typos!")
+  if (!all(x %in% names(data)) || !all(y %in% names(data))) {
+    stop("The names you entered for x and y are not available in the dataset. Make sure there are no typos!", call. = FALSE)
   }
 
   if (ci == "default") ci <- 0.95
-  if (partial == FALSE & (partial_bayesian | multilevel)) partial <- TRUE
+  if (partial == FALSE && (partial_bayesian || multilevel)) partial <- TRUE
 
   # Make sure factor is no factor
   if (!method %in% c("tetra", "tetrachoric", "poly", "polychoric")) {
@@ -154,7 +154,7 @@ cor_test <- function(data,
 
     # semi-partial
     if (partial == "semi") {
-      stop("Semi-partial correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Semi-partial correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     }
   }
 
@@ -198,8 +198,8 @@ cor_test <- function(data,
 
   # Find method
   method <- tolower(method)
-  if (method == "auto" & bayesian == FALSE) method <- .find_correlationtype(data, x, y)
-  if (method == "auto" & bayesian == TRUE) method <- "pearson"
+  if (method == "auto" && bayesian == FALSE) method <- .find_correlationtype(data, x, y)
+  if (method == "auto" && bayesian == TRUE) method <- "pearson"
 
   # Frequentist
   if (bayesian == FALSE) {
@@ -234,23 +234,23 @@ cor_test <- function(data,
     # Bayesian
   } else {
     if (method %in% c("tetra", "tetrachoric")) {
-      stop("Tetrachoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Tetrachoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("poly", "polychoric")) {
-      stop("Polychoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Polychoric Bayesian correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("biserial", "pointbiserial", "point-biserial")) {
-      stop("Biserial Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Biserial Bayesian correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("biweight")) {
-      stop("Biweight Bayesian correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Biweight Bayesian correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("distance")) {
-      stop("Bayesian distance correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Bayesian distance correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
-      stop("Bayesian Percentage Bend correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Bayesian Percentage Bend correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("blomqvist", "median", "medial")) {
-      stop("Bayesian Blomqvist correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
+      stop("Bayesian Blomqvist correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).", call. = FALSE)
     } else if (method %in% c("hoeffding")) {
-      stop("Bayesian Hoeffding's correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).")
+      stop("Bayesian Hoeffding's correlations are not supported yet. Check-out the BBcor package (https://github.com/donaldRwilliams/BBcor).", call. = FALSE)
     } else if (method %in% c("gamma")) {
-      stop("Bayesian gamma correlations are not supported yet. Get in touch if you want to contribute.")
+      stop("Bayesian gamma correlations are not supported yet. Get in touch if you want to contribute.", call. = FALSE)
     } else if (method %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
       out <- .cor_test_shepherd(data, x, y, ci = ci, bayesian = TRUE, ...)
     } else {
