@@ -16,12 +16,12 @@
 cor_to_cov <- function(cor, sd = NULL, variance = NULL, tol = .Machine$double.eps^(2 / 3)) {
   # valid matrix checks
   if (!isSquare(cor)) {
-    stop("The matrix should be a square matrix.")
+    stop("The matrix should be a square matrix.", call. = FALSE)
   }
 
   if (is.null(sd)) {
     if (is.null(variance)) {
-      stop("SD or variance of variables needs to be provided.")
+      stop("SD or variance of variables needs to be provided.", call. = FALSE)
     } else {
       sd <- sqrt(variance)
     }
@@ -30,11 +30,11 @@ cor_to_cov <- function(cor, sd = NULL, variance = NULL, tol = .Machine$double.ep
   n <- nrow(cor)
 
   if (n != length(sd)) {
-    stop("The length of 'sd' or 'variance' should be the same as the number of rows of the matrix.")
+    stop("The length of 'sd' or 'variance' should be the same as the number of rows of the matrix.", call. = FALSE)
   }
 
   if (length(sd[sd > 0]) != n) {
-    stop("The elements in 'sd' or 'variance' should all be non-negative.")
+    stop("The elements in 'sd' or 'variance' should all be non-negative.", call. = FALSE)
   }
 
   if (isSymmetric(cor)) {
@@ -49,8 +49,8 @@ cor_to_cov <- function(cor, sd = NULL, variance = NULL, tol = .Machine$double.ep
   } else {
     is_triangular <- FALSE
   }
-  if (!is_symmetric & !is_triangular) {
-    stop("'cor' should be either a symmetric or a triangular matrix")
+  if (!is_symmetric && !is_triangular) {
+    stop("'cor' should be either a symmetric or a triangular matrix", call. = FALSE)
   }
 
   cov <- diag(sd) %*% cor %*% diag(sd)
